===============
Getting Started
===============

Installation
------------

PyQtRibbon is distribued to `PyPI <https://pypi.org/project/pyqtribbon/>`_, you can use pip to install it:

.. code-block:: sh

    pip install pyqtribbon

You can also install the package from source:

.. code-block:: sh

    pip install git+https://github.com/haiiliin/pyqtribbon.git@main
